"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.TSPixels2Inches = exports.TSInches2Pixels = exports.TSPixels2mm = exports.TSPixels2cm = exports.TScm2Pixels = exports.TSmm2Pixels = exports.TSRect = exports.TSDocumentFormats = void 0;
const commons_1 = require("./commons");
exports.TSDocumentFormats = {
    letter: { w: TSInches2Pixels(8.5), h: TSInches2Pixels(11) },
    legal: { w: TSInches2Pixels(8.5), h: TSInches2Pixels(14) },
    tabloid: { w: TSInches2Pixels(11), h: TSInches2Pixels(17) },
    a0: { w: TSmm2Pixels(841), h: TSmm2Pixels(1189) },
    a1: { w: TSmm2Pixels(594), h: TSmm2Pixels(841) },
    a2: { w: TSmm2Pixels(420), h: TSmm2Pixels(594) },
    a3: { w: TSmm2Pixels(297), h: TSmm2Pixels(420) },
    a4: { w: TSmm2Pixels(210), h: TSmm2Pixels(294) },
    a5: { w: TSmm2Pixels(148), h: TSmm2Pixels(210) },
    a6: { w: TSmm2Pixels(105), h: TSmm2Pixels(148) }
};
class TSRect {
    constructor() {
        const n = arguments.length;
        switch (n) {
            case 0:
                throw 'Bad TSRect() constructor: no arguments provided';
            case 1: {
                if (!(arguments[0] instanceof TSRect)) {
                    const r = arguments[0];
                    this.x = r.x;
                    this.y = r.y;
                    this.w = r.w;
                    this.h = r.h;
                    break;
                }
                else {
                    throw 'Bad TSRect() constructor: should have a TSRect single argument';
                }
            }
            case 2:
                if (!(0, commons_1.$isobject)(arguments[0]) || !('x' in arguments[0]) || !('y' in arguments[0]) ||
                    !(0, commons_1.$isobject)(arguments[1]) || !('x' in arguments[1]) || !('y' in arguments[1])) {
                    throw 'Bad TSRect() constructor: bad TSOrigin or TSSize parameter';
                }
                this.x = arguments[0].x;
                this.y = arguments[0].y;
                this.w = arguments[1].w;
                this.h = arguments[2].h;
                break;
            case 3:
                if (!(0, commons_1.$isobject)(arguments[0]) || !('x' in arguments[0]) || !('y' in arguments[0]) ||
                    !(0, commons_1.$isnumber)(arguments[1]) || !(0, commons_1.$isnumber)(arguments[2])) {
                    throw 'Bad TSRect() constructor: bad TSOrigin or number parameter';
                }
                this.x = arguments[0].x;
                this.y = arguments[0].y;
                this.w = arguments[1];
                this.h = arguments[2];
                break;
            case 4:
                if (!(0, commons_1.$isnumber)(arguments[0]) || !(0, commons_1.$isnumber)(arguments[1]) ||
                    !(0, commons_1.$isnumber)(arguments[2]) || !(0, commons_1.$isnumber)(arguments[3])) {
                    throw 'Bad TSRect() constructor: bad number parameter';
                }
                this.x = arguments[0];
                this.y = arguments[1];
                this.w = arguments[2];
                this.h = arguments[3];
                break;
            default:
                throw 'Bad TSRect() constructor : too much arguments';
        }
    }
    get origin() { return { x: this.x, y: this.y }; }
    get size() { return { w: this.w, h: this.h }; }
    get minX() { return this.x; }
    get minY() { return this.y; }
    get maxX() { return this.x + this.w; }
    get maxY() { return this.y + this.h; }
    get midX() { return this.x + this.w / 2; }
    get midY() { return this.y + this.h / 2; }
}
exports.TSRect = TSRect;
function TSmm2Pixels(mm) { return mm * 45 / 16; }
exports.TSmm2Pixels = TSmm2Pixels;
function TScm2Pixels(cm) { return cm * 225 / 8; }
exports.TScm2Pixels = TScm2Pixels;
function TSPixels2cm(pixels) { return pixels * 8 / 225; }
exports.TSPixels2cm = TSPixels2cm;
function TSPixels2mm(pixels) { return pixels * 16 / 45; }
exports.TSPixels2mm = TSPixels2mm;
function TSInches2Pixels(inches) { return inches * 72; }
exports.TSInches2Pixels = TSInches2Pixels;
function TSPixels2Inches(pixels) { return pixels / 72; }
exports.TSPixels2Inches = TSPixels2Inches;
//# sourceMappingURL=tsgeometry.js.map